@@ -3,7 +3,7 @@ package Text::Table::Span;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-02-20'; # DATE
 our $DIST = 'Text-Table-Span'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -544,7 +544,7 @@ sub generate_table {
 }
 
 1;
-# ABSTRACT: Text::Table::Tiny + support for column/row spans
+# ABSTRACT: (DEPRECATED) Text::Table::Tiny + support for column/row spans
 
 __END__
 
@@ -554,11 +554,11 @@ __END__
 
 =head1 NAME
 
-Text::Table::Span - Text::Table::Tiny + support for column/row spans
+Text::Table::Span - (DEPRECATED) Text::Table::Tiny + support for column/row spans
 
 =head1 VERSION
 
-This document describes version 0.008 of Text::Table::Span (from Perl distribution Text-Table-Span), released on 2021-02-20.
+This document describes version 0.009 of Text::Table::Span (from Perl distribution Text-Table-Span), released on 2021-02-20.
 
 =head1 SYNOPSIS
 
@@ -730,6 +730,9 @@ then the output will be something like this:
 
 =head1 DESCRIPTION
 
+B<DEPRECATION NOTICE:> This module has been renamed to L<Text::Table::More>.
+Please use the new name.
+
 This module is like L<Text::Table::Tiny> (0.04) with added support for
 column/row spans, and border style.
 
